@@ -1,5 +1,5 @@
 library(rnndescent)
-context("overlap")
+context("Overlap")
 
 ui10_bf <- brute_force_knn(ui10, k = 4)
 
